asr.test.test\_relax
====================

.. automodule:: asr.test.test_relax

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_relax_basic
   .. autofunction:: test_relax_bn_gpaw
   .. autofunction:: test_relax_emt
   .. autofunction:: test_relax_emt_fail_broken_symmetry
   .. autofunction:: test_relax_find_higher_symmetry
   .. autofunction:: test_relax_magmoms
   .. autofunction:: test_relax_si_gpaw
   
   

   
   
   

   
   
   